==> home-library-jcr-1.5.1-20130524.163824-3-sources.jar: org/gcube/portlets/user/homelibrary/jcr/home/JCRHome.java <==
package org.gcube.portlets.user.homelibrary.jcr.home;

import java.io.File;
import java.util.List;

import javax.jcr.RepositoryException;
import javax.jcr.Session;

import org.gcube.common.core.scope.GCUBEScope;
import org.gcube.common.core.utils.logging.GCUBEClientLog;
import org.gcube.portlets.user.homelibrary.home.Home;
import org.gcube.portlets.user.homelibrary.home.HomeManager;
import org.gcube.portlets.user.homelibrary.home.User;
import org.gcube.portlets.user.homelibrary.home.data.ApplicationsArea;
import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.portlets.user.homelibrary.home.workspace.Workspace;
import org.gcube.portlets.user.homelibrary.home.workspace.exceptions.WorkspaceFolderNotFoundException;
import org.gcube.portlets.user.homelibrary.jcr.JCRUser;
import org.gcube.portlets.user.homelibrary.jcr.data.JCRApplicationsArea;
import org.gcube.portlets.user.homelibrary.jcr.repository.JCRRepository;
import org.gcube.portlets.user.homelibrary.jcr.workspace.JCRWorkspace;



public class JCRHome implements Home {

	private final HomeManager homeManager;
	private final JCRUser owner;

	private final File persistenceFolder;
	private final JCRRepository repository;
	private final Workspace workspace;
	
	private GCUBEClientLog logger;
	
	public JCRHome(HomeManager homeManager, JCRUser user, File persistenceFolder) throws Exception {
		super();
		
		setupLogger();
		
		this.owner = user;
		this.persistenceFolder = persistenceFolder;
		this.homeManager = homeManager;
		this.repository = new JCRRepository(user);
		this.workspace = new JCRWorkspace(this, repository);	
	}
	
	
	private void setupLogger() {
				
		logger = new GCUBEClientLog(this);
	}

	public void setScope(GCUBEScope scope) throws InternalErrorException {
		owner.setScope(scope);
		
		Session session = JCRRepository.getSession();
		try {
			repository.setScope(session, scope.toString());
			session.save();
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} finally {
			session.logout();
		}	
	}
	

	
	@Override
	public HomeManager getHomeManager() {
		return homeManager;
	}
	

	@Override
	public User getOwner() {
		return owner;
	}

	@Override
	public Workspace getWorkspace() throws WorkspaceFolderNotFoundException,
			InternalErrorException {
		return workspace;
	}

	@Override
	public ApplicationsArea getDataArea() throws InternalErrorException {
		//TODO
		return null;
	}

	@Override
	public List<String> listScopes() throws  InternalErrorException {
		
		try {
			return repository.listScopes();
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		}
	}

}

==> home-library-jcr-1.6.1-20131007.173427-5-sources.jar: org/gcube/portlets/user/homelibrary/jcr/home/JCRHome.java <==
package org.gcube.portlets.user.homelibrary.jcr.home;

import java.io.File;
import java.util.List;

import javax.jcr.RepositoryException;
import javax.jcr.Session;

import org.gcube.common.core.scope.GCUBEScope;
import org.gcube.portlets.user.homelibrary.home.Home;
import org.gcube.portlets.user.homelibrary.home.HomeManager;
import org.gcube.portlets.user.homelibrary.home.User;
import org.gcube.portlets.user.homelibrary.home.data.ApplicationsArea;
import org.gcube.portlets.user.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.portlets.user.homelibrary.home.workspace.Workspace;
import org.gcube.portlets.user.homelibrary.home.workspace.exceptions.WorkspaceFolderNotFoundException;
import org.gcube.portlets.user.homelibrary.jcr.JCRUser;
import org.gcube.portlets.user.homelibrary.jcr.data.JCRApplicationsArea;
import org.gcube.portlets.user.homelibrary.jcr.repository.JCRRepository;
import org.gcube.portlets.user.homelibrary.jcr.workspace.JCRWorkspace;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;



public class JCRHome implements Home {

	private final HomeManager homeManager;
	private final JCRUser owner;

	private final File persistenceFolder;
	private final JCRRepository repository;
	private final JCRWorkspace workspace;
	private final JCRApplicationsArea applicationArea;
	
	private Logger logger;
	
	public JCRHome(HomeManager homeManager, JCRUser user, File persistenceFolder) throws Exception {
		super();
		
		setupLogger();
		
		this.owner = user;
		this.persistenceFolder = persistenceFolder;
		this.homeManager = homeManager;
		this.repository = new JCRRepository(user);
		this.workspace = new JCRWorkspace(this, repository);
		this.applicationArea = new JCRApplicationsArea(workspace);
		
	}
	
	
	private void setupLogger() {
				
		logger = LoggerFactory.getLogger(JCRHome.class);
	}

	public void setScope(GCUBEScope scope) throws InternalErrorException {
		owner.setScope(scope);
		
		Session session = JCRRepository.getSession();
		try {
			repository.setScope(session, scope.toString());
			session.save();
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		} finally {
			session.logout();
		}	
	}
	

	
	@Override
	public HomeManager getHomeManager() {
		return homeManager;
	}
	

	@Override
	public User getOwner() {
		return owner;
	}

	@Override
	public Workspace getWorkspace() throws WorkspaceFolderNotFoundException,
			InternalErrorException {
		return workspace;
	}

	@Override
	public ApplicationsArea getDataArea() throws InternalErrorException {
		//TODO
		return applicationArea;
	}

	@Override
	public List<String> listScopes() throws  InternalErrorException {
		
		try {
			return repository.listScopes();
		} catch (RepositoryException e) {
			throw new InternalErrorException(e);
		}
	}

}
